@@ -40,8 +40,6 @@
 
 static GType column_types[E_ALARM_LIST_NUM_COLUMNS];
 
-static void         e_alarm_list_init            (EAlarmList         *file_list);
-static void         e_alarm_list_class_init      (EAlarmListClass    *class);
 static void         e_alarm_list_tree_model_init (GtkTreeModelIface  *iface);
 static GtkTreeModelFlags e_alarm_list_get_flags       (GtkTreeModel       *tree_model);
 static gint         e_alarm_list_get_n_columns   (GtkTreeModel       *tree_model);
@@ -73,50 +71,18 @@ static gboolean     e_alarm_list_iter_parent     (GtkTreeModel       *tree_model
 						  GtkTreeIter        *iter,
 						  GtkTreeIter        *child);
 
-static GObjectClass *parent_class = NULL;
-
-GType
-e_alarm_list_get_type (void)
-{
-	static GType alarm_list_type = 0;
-
-	if (!alarm_list_type) {
-		static const GTypeInfo alarm_list_info =
-		{
-			sizeof (EAlarmListClass),
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-			(GClassInitFunc) e_alarm_list_class_init,
-			NULL,		/* class_finalize */
-			NULL,		/* class_data */
-			sizeof (EAlarmList),
-			0,
-			(GInstanceInitFunc) e_alarm_list_init,
-		};
-
-		static const GInterfaceInfo tree_model_info =
-		{
-			(GInterfaceInitFunc) e_alarm_list_tree_model_init,
-			NULL,
-			NULL
-		};
-
-		column_types[E_ALARM_LIST_COLUMN_DESCRIPTION] = G_TYPE_STRING;
-
-		alarm_list_type = g_type_register_static (G_TYPE_OBJECT, "EAlarmList",
-							  &alarm_list_info, 0);
-		g_type_add_interface_static (alarm_list_type,
-					     GTK_TYPE_TREE_MODEL,
-					     &tree_model_info);
-	}
-
-	return alarm_list_type;
-}
+G_DEFINE_TYPE_WITH_CODE (
+	EAlarmList,
+	e_alarm_list,
+	G_TYPE_OBJECT,
+	G_IMPLEMENT_INTERFACE (
+		GTK_TYPE_TREE_MODEL,
+		e_alarm_list_tree_model_init))
 
 static void
 e_alarm_list_class_init (EAlarmListClass *class)
 {
-	parent_class = g_type_class_peek_parent (class);
+	column_types[E_ALARM_LIST_COLUMN_DESCRIPTION] = G_TYPE_STRING;
 }
 
 static void
@@ -176,7 +142,8 @@ all_rows_deleted (EAlarmList *alarm_list)
 }
 
 static void
-row_deleted (EAlarmList *alarm_list, gint n)
+row_deleted (EAlarmList *alarm_list,
+             gint n)
 {
 	GtkTreePath *path;
 
@@ -187,7 +154,8 @@ row_deleted (EAlarmList *alarm_list, gint n)
 }
 
 static void
-row_added (EAlarmList *alarm_list, gint n)
+row_added (EAlarmList *alarm_list,
+           gint n)
 {
 	GtkTreePath *path;
 	GtkTreeIter  iter;
@@ -202,7 +170,8 @@ row_added (EAlarmList *alarm_list, gint n)
 }
 
 static void
-row_updated (EAlarmList *alarm_list, gint n)
+row_updated (EAlarmList *alarm_list,
+             gint n)
 {
 	GtkTreePath *path;
 	GtkTreeIter  iter;
@@ -238,7 +207,7 @@ e_alarm_list_get_n_columns (GtkTreeModel *tree_model)
 
 static GType
 e_alarm_list_get_column_type (GtkTreeModel *tree_model,
-			      gint          index)
+                              gint index)
 {
 	EAlarmList *alarm_list = (EAlarmList *) tree_model;
 
@@ -251,7 +220,8 @@ e_alarm_list_get_column_type (GtkTreeModel *tree_model,
 }
 
 const ECalComponentAlarm *
-e_alarm_list_get_alarm (EAlarmList *alarm_list, GtkTreeIter *iter)
+e_alarm_list_get_alarm (EAlarmList *alarm_list,
+                        GtkTreeIter *iter)
 {
 	g_return_val_if_fail (IS_VALID_ITER (alarm_list, iter), NULL);
 
@@ -271,8 +241,9 @@ copy_alarm (const ECalComponentAlarm *alarm)
 }
 
 void
-e_alarm_list_set_alarm (EAlarmList *alarm_list, GtkTreeIter *iter,
-			const ECalComponentAlarm *alarm)
+e_alarm_list_set_alarm (EAlarmList *alarm_list,
+                        GtkTreeIter *iter,
+                        const ECalComponentAlarm *alarm)
 {
 	ECalComponentAlarm *alarm_old;
 
@@ -285,8 +256,9 @@ e_alarm_list_set_alarm (EAlarmList *alarm_list, GtkTreeIter *iter,
 }
 
 void
-e_alarm_list_append (EAlarmList *alarm_list, GtkTreeIter *iter,
-		     const ECalComponentAlarm *alarm)
+e_alarm_list_append (EAlarmList *alarm_list,
+                     GtkTreeIter *iter,
+                     const ECalComponentAlarm *alarm)
 {
 	g_return_if_fail (alarm != NULL);
 
@@ -300,7 +272,8 @@ e_alarm_list_append (EAlarmList *alarm_list, GtkTreeIter *iter,
 }
 
 void
-e_alarm_list_remove (EAlarmList *alarm_list, GtkTreeIter *iter)
+e_alarm_list_remove (EAlarmList *alarm_list,
+                     GtkTreeIter *iter)
 {
 	gint n;
 
@@ -328,7 +301,9 @@ e_alarm_list_clear (EAlarmList *alarm_list)
 }
 
 static gboolean
-e_alarm_list_get_iter (GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreePath *path)
+e_alarm_list_get_iter (GtkTreeModel *tree_model,
+                       GtkTreeIter *iter,
+                       GtkTreePath *path)
 {
 	EAlarmList *alarm_list = (EAlarmList *) tree_model;
 	GList      *l;
@@ -354,7 +329,7 @@ e_alarm_list_get_iter (GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreePath
 
 static GtkTreePath *
 e_alarm_list_get_path (GtkTreeModel *tree_model,
-		       GtkTreeIter  *iter)
+                       GtkTreeIter *iter)
 {
 	EAlarmList  *alarm_list = (EAlarmList *) tree_model;
 	GtkTreePath *retval;
@@ -539,9 +514,9 @@ get_alarm_string (ECalComponentAlarm *alarm)
 
 static void
 e_alarm_list_get_value (GtkTreeModel *tree_model,
-			GtkTreeIter  *iter,
-			gint          column,
-			GValue       *value)
+                        GtkTreeIter *iter,
+                        gint column,
+                        GValue *value)
 {
 	EAlarmList        *alarm_list = E_ALARM_LIST (tree_model);
 	ECalComponentAlarm *alarm;
@@ -574,8 +549,8 @@ e_alarm_list_get_value (GtkTreeModel *tree_model,
 }
 
 static gboolean
-e_alarm_list_iter_next (GtkTreeModel  *tree_model,
-			GtkTreeIter   *iter)
+e_alarm_list_iter_next (GtkTreeModel *tree_model,
+                        GtkTreeIter *iter)
 {
 	GList *l;
 
@@ -597,8 +572,8 @@ e_alarm_list_iter_next (GtkTreeModel  *tree_model,
 
 static gboolean
 e_alarm_list_iter_children (GtkTreeModel *tree_model,
-			    GtkTreeIter  *iter,
-			    GtkTreeIter  *parent)
+                            GtkTreeIter *iter,
+                            GtkTreeIter *parent)
 {
 	EAlarmList *alarm_list = E_ALARM_LIST (tree_model);
 
@@ -619,7 +594,7 @@ e_alarm_list_iter_children (GtkTreeModel *tree_model,
 
 static gboolean
 e_alarm_list_iter_has_child (GtkTreeModel *tree_model,
-			     GtkTreeIter  *iter)
+                             GtkTreeIter *iter)
 {
 	g_return_val_if_fail (IS_VALID_ITER (E_ALARM_LIST (tree_model), iter), FALSE);
 	return FALSE;
@@ -627,7 +602,7 @@ e_alarm_list_iter_has_child (GtkTreeModel *tree_model,
 
 static gint
 e_alarm_list_iter_n_children (GtkTreeModel *tree_model,
-			      GtkTreeIter  *iter)
+                              GtkTreeIter *iter)
 {
 	EAlarmList *alarm_list = E_ALARM_LIST (tree_model);
 
@@ -642,9 +617,9 @@ e_alarm_list_iter_n_children (GtkTreeModel *tree_model,
 
 static gboolean
 e_alarm_list_iter_nth_child (GtkTreeModel *tree_model,
-			     GtkTreeIter  *iter,
-			     GtkTreeIter  *parent,
-			     gint          n)
+                             GtkTreeIter *iter,
+                             GtkTreeIter *parent,
+                             gint n)
 {
 	EAlarmList *alarm_list = E_ALARM_LIST (tree_model);
 
@@ -670,8 +645,8 @@ e_alarm_list_iter_nth_child (GtkTreeModel *tree_model,
 
 static gboolean
 e_alarm_list_iter_parent (GtkTreeModel *tree_model,
-			  GtkTreeIter  *iter,
-			  GtkTreeIter  *child)
+                          GtkTreeIter *iter,
+                          GtkTreeIter *child)
 {
 	return FALSE;
 }
