@@ -861,12 +861,22 @@ efh_busy (EMFormat *emf)
 
 	return (priv->format_id != -1);
 }
+
 static void
 efh_base_init (EMFormatHTMLClass *class)
 {
 	efh_builtin_init (class);
 }
 
+static void
+efh_constructed (GObject *object)
+{
+	/* Chain up to parent's constructed() method. */
+	G_OBJECT_CLASS (parent_class)->constructed (object);
+
+	e_extensible_load_extensions (E_EXTENSIBLE (object));
+}
+
 static void
 efh_class_init (EMFormatHTMLClass *class)
 {
@@ -878,6 +888,7 @@ efh_class_init (EMFormatHTMLClass *class)
 	g_type_class_add_private (class, sizeof (EMFormatHTMLPrivate));
 
 	object_class = G_OBJECT_CLASS (class);
+	object_class->constructed = efh_constructed;
 	object_class->set_property = efh_set_property;
 	object_class->get_property = efh_get_property;
 	object_class->finalize = efh_finalize;
@@ -1104,8 +1115,6 @@ efh_init (EMFormatHTML *efh,
 		CAMEL_MIME_FILTER_TOHTML_MARK_CITATION;
 	efh->show_icon = TRUE;
 	efh->state = EM_FORMAT_HTML_STATE_NONE;
-
-	e_extensible_load_extensions (E_EXTENSIBLE (efh));
 }
 
 GType
@@ -1702,6 +1711,12 @@ badurl:
 
 /* ********************************************************************** */
 
+static void
+emfh_write_related (EMFormat *emf,
+                    CamelStream *stream,
+                    EMFormatPURI *puri,
+                    GCancellable *cancellable);
+
 static void
 efh_url_requested (GtkHTML *html,
                    const gchar *url,
@@ -1714,6 +1729,26 @@ efh_url_requested (GtkHTML *html,
 	d(printf("url requested, html = %p, url '%s'\n", html, url));
 
 	puri = em_format_find_visible_puri ((EMFormat *) efh, url);
+	if (!puri && url && g_str_has_prefix (url, "cid:")) {
+		GHashTableIter iter;
+		gpointer key, value;
+
+		g_hash_table_iter_init (&iter, ((EMFormat *) efh)->pending_uri_table);
+		while (g_hash_table_iter_next (&iter, &key, &value)) {
+			puri = value;
+
+			if (puri->part && g_strcmp0 (url + 4, camel_mime_part_get_content_id (puri->part)) == 0)
+				break;
+
+			puri = NULL;
+		}
+
+		if (puri) {
+			/* it's expected as cid:, with its content, thus write it as such */
+			puri->func = emfh_write_related;
+		}
+	}
+
 	if (puri) {
 		CamelDataWrapper *dw = camel_medium_get_content ((CamelMedium *) puri->part);
 		CamelContentType *ct = dw ? dw->mime_type : NULL;
